@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Mirantis Inc.
+# Copyright (c) 2015 Intel Corporation
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,9 +15,9 @@
 
 from sahara.i18n import _
 from sahara.plugins.cdh import cloudera_utils as cu
-from sahara.plugins.cdh.v5_3_0 import config_helper
-from sahara.plugins.cdh.v5_3_0 import plugin_utils as pu
-from sahara.plugins.cdh.v5_3_0 import validation
+from sahara.plugins.cdh.v5_5_0 import config_helper
+from sahara.plugins.cdh.v5_5_0 import plugin_utils as pu
+from sahara.plugins.cdh.v5_5_0 import validation
 from sahara.swift import swift_helper
 from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import configs as s_cfg
@@ -38,23 +38,28 @@ SOLR_SERVICE_TYPE = 'SOLR'
 SQOOP_SERVICE_TYPE = 'SQOOP'
 KS_INDEXER_SERVICE_TYPE = 'KS_INDEXER'
 IMPALA_SERVICE_TYPE = 'IMPALA'
+KMS_SERVICE_TYPE = 'KMS'
+KAFKA_SERVICE_TYPE = 'KAFKA'
 
-c_helper = config_helper.ConfigHelperV530()
+c_helper = config_helper.ConfigHelperV550()
 
 
-class ClouderaUtilsV530(cu.ClouderaUtils):
+class ClouderaUtilsV550(cu.ClouderaUtils):
     FLUME_SERVICE_NAME = 'flume01'
     SOLR_SERVICE_NAME = 'solr01'
     SQOOP_SERVICE_NAME = 'sqoop01'
     KS_INDEXER_SERVICE_NAME = 'ks_indexer01'
     IMPALA_SERVICE_NAME = 'impala01'
     SENTRY_SERVICE_NAME = 'sentry01'
+    KMS_SERVICE_NAME = 'kms01'
     CM_API_VERSION = 8
+    NAME_SERVICE = 'nameservice01'
+    KAFKA_SERVICE_NAME = 'kafka01'
 
     def __init__(self):
         cu.ClouderaUtils.__init__(self)
-        self.pu = pu.PluginUtilsV530()
-        self.validator = validation.ValidatorV530
+        self.pu = pu.PluginUtilsV550()
+        self.validator = validation.ValidatorV550
 
     def get_service_by_role(self, role, cluster=None, instance=None):
         cm_cluster = None
@@ -77,8 +82,16 @@ class ClouderaUtilsV530(cu.ClouderaUtils):
             return cm_cluster.get_service(self.KS_INDEXER_SERVICE_NAME)
         elif role in ['CATALOGSERVER', 'STATESTORE', 'IMPALAD', 'LLAMA']:
             return cm_cluster.get_service(self.IMPALA_SERVICE_NAME)
+        elif role in ['KMS']:
+            return cm_cluster.get_service(self.KMS_SERVICE_NAME)
+        elif role in ['JOURNALNODE']:
+            return cm_cluster.get_service(self.HDFS_SERVICE_NAME)
+        elif role in ['YARN_STANDBYRM']:
+            return cm_cluster.get_service(self.YARN_SERVICE_NAME)
+        elif role in ['KAFKA_BROKER']:
+            return cm_cluster.get_service(self.KAFKA_SERVICE_NAME)
         else:
-            return super(ClouderaUtilsV530, self).get_service_by_role(
+            return super(ClouderaUtilsV550, self).get_service_by_role(
                 role, cluster, instance)
 
     @cpo.event_wrapper(
@@ -129,6 +142,12 @@ class ClouderaUtilsV530(cu.ClouderaUtils):
         if self.pu.get_catalogserver(cluster):
             cm_cluster.create_service(self.IMPALA_SERVICE_NAME,
                                       IMPALA_SERVICE_TYPE)
+        if self.pu.get_kms(cluster):
+            cm_cluster.create_service(self.KMS_SERVICE_NAME,
+                                      KMS_SERVICE_TYPE)
+        if len(self.pu.get_kafka_brokers(cluster)) > 0:
+            cm_cluster.create_service(self.KAFKA_SERVICE_NAME,
+                                      KAFKA_SERVICE_TYPE)
 
     def await_agents(self, cluster, instances):
         self._await_agents(cluster, instances, c_helper.AWAIT_AGENTS_TIMEOUT)
@@ -205,6 +224,16 @@ class ClouderaUtilsV530(cu.ClouderaUtils):
             impala.update_config(self._get_configs(IMPALA_SERVICE_TYPE,
                                                    cluster=cluster))
 
+        if self.pu.get_kms(cluster):
+            kms = cm_cluster.get_service(self.KMS_SERVICE_NAME)
+            kms.update_config(self._get_configs(KMS_SERVICE_TYPE,
+                                                cluster=cluster))
+
+        if len(self.pu.get_kafka_brokers(cluster)) > 0:
+            kafka = cm_cluster.get_service(self.KAFKA_SERVICE_NAME)
+            kafka.update_config(self._get_configs(KAFKA_SERVICE_TYPE,
+                                                  cluster=cluster))
+
     def _get_configs(self, service, cluster=None, instance=None):
         def get_hadoop_dirs(mount_points, suffix):
             return ','.join([x + suffix for x in mount_points])
@@ -219,8 +248,10 @@ class ClouderaUtilsV530(cu.ClouderaUtils):
             ks_count =\
                 self.validator._get_inst_count(cluster,
                                                'KEY_VALUE_STORE_INDEXER')
-            imp_count = self.validator._get_inst_count(cluster,
-                                                       'IMPALA_CATALOGSERVER')
+            kms_count = self.validator._get_inst_count(cluster, 'KMS')
+            imp_count =\
+                self.validator._get_inst_count(cluster,
+                                               'IMPALA_CATALOGSERVER')
             hive_count = self.validator._get_inst_count(cluster,
                                                         'HIVE_METASTORE')
             slr_count = self.validator._get_inst_count(cluster, 'SOLR_SERVER')
@@ -236,6 +267,7 @@ class ClouderaUtilsV530(cu.ClouderaUtils):
                         self.ZOOKEEPER_SERVICE_NAME if zk_count else '',
                     'dfs_block_local_path_access_user':
                         'impala' if imp_count else '',
+                    'kms_service': self.KMS_SERVICE_NAME if kms_count else '',
                     'core_site_safety_valve': core_site_safety_valve
                 },
                 'HIVE': {
@@ -344,13 +376,20 @@ class ClouderaUtilsV530(cu.ClouderaUtils):
                         self.pu.db_helper.get_sentry_db_password(cluster)
                 }
             }
-
+            kafka_confs = {
+                'KAFKA': {
+                    'zookeeper_service': self.ZOOKEEPER_SERVICE_NAME
+                }
+            }
             all_confs = s_cfg.merge_configs(all_confs, hue_confs)
             all_confs = s_cfg.merge_configs(all_confs, hive_confs)
             all_confs = s_cfg.merge_configs(all_confs, sentry_confs)
+            all_confs = s_cfg.merge_configs(all_confs, kafka_confs)
             all_confs = s_cfg.merge_configs(all_confs, cluster.cluster_configs)
 
         if instance:
+            snt_count = self.validator._get_inst_count(instance.cluster,
+                                                       'SENTRY_SERVER')
             paths = instance.storage_paths()
 
             instance_default_confs = {
@@ -368,7 +407,11 @@ class ClouderaUtilsV530(cu.ClouderaUtils):
                 },
                 'NODEMANAGER': {
                     'yarn_nodemanager_local_dirs':
-                        get_hadoop_dirs(paths, '/yarn/local')
+                        get_hadoop_dirs(paths, '/yarn/local'),
+                    'container_executor_allowed_system_users':
+                        "nobody,impala,hive,llama,hdfs,yarn,mapred,"
+                        "spark,oozie",
+                    "container_executor_banned_users": "bin"
                 },
                 'SERVER': {
                     'maxSessionTimeout': 60000
@@ -393,3 +436,36 @@ class ClouderaUtilsV530(cu.ClouderaUtils):
             all_confs = s_cfg.merge_configs(all_confs, instance_default_confs)
 
         return all_confs.get(service, {})
+
+    @cpo.event_wrapper(
+        True, step=_("Enable NameNode HA"), param=('cluster', 1))
+    @cu.cloudera_cmd
+    def enable_namenode_ha(self, cluster):
+        standby_nn = self.pu.get_secondarynamenode(cluster)
+        standby_nn_host_name = standby_nn.fqdn()
+        jns = self.pu.get_jns(cluster)
+        jn_list = []
+        for index, jn in enumerate(jns):
+            jn_host_name = jn.fqdn()
+            jn_list.append({'jnHostId': jn_host_name,
+                            'jnName': 'JN%i' % index,
+                            'jnEditsDir': '/dfs/jn'
+                            })
+        cm_cluster = self.get_cloudera_cluster(cluster)
+        hdfs = cm_cluster.get_service(self.HDFS_SERVICE_NAME)
+        nn = hdfs.get_roles_by_type('NAMENODE')[0]
+
+        yield hdfs.enable_nn_ha(active_name=nn.name,
+                                standby_host_id=standby_nn_host_name,
+                                nameservice=self.NAME_SERVICE, jns=jn_list
+                                )
+
+    @cpo.event_wrapper(
+        True, step=_("Enable ResourceManager HA"), param=('cluster', 1))
+    @cu.cloudera_cmd
+    def enable_resourcemanager_ha(self, cluster):
+        new_rm = self.pu.get_stdb_rm(cluster)
+        new_rm_host_name = new_rm.fqdn()
+        cm_cluster = self.get_cloudera_cluster(cluster)
+        yarn = cm_cluster.get_service(self.YARN_SERVICE_NAME)
+        yield yarn.enable_rm_ha(new_rm_host_id=new_rm_host_name)
