@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Mirantis Inc.
+# Copyright (c) 2016 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,34 +18,34 @@ from sahara.plugins import provisioning as p
 from sahara.utils import files as f
 
 
-class ConfigHelperV540(c_h.ConfigHelper):
-    path_to_config = 'plugins/cdh/v5_4_0/resources/'
+class ConfigHelperV590(c_h.ConfigHelper):
+    path_to_config = 'plugins/cdh/v5_9_0/resources/'
 
     CDH5_UBUNTU_REPO = (
         'deb [arch=amd64] http://archive.cloudera.com/cdh5'
-        '/ubuntu/precise/amd64/cdh precise-cdh5.4.0 contrib'
+        '/ubuntu/trusty/amd64/cdh trusty-cdh5.9.0 contrib'
         '\ndeb-src http://archive.cloudera.com/cdh5/ubuntu'
-        '/precise/amd64/cdh precise-cdh5.4.0 contrib')
+        '/trusty/amd64/cdh trusty-cdh5.9.0 contrib')
 
     DEFAULT_CDH5_UBUNTU_REPO_KEY_URL = (
         'http://archive.cloudera.com/cdh5/ubuntu'
-        '/precise/amd64/cdh/archive.key')
+        '/trusty/amd64/cdh/archive.key')
 
     CM5_UBUNTU_REPO = (
         'deb [arch=amd64] http://archive.cloudera.com/cm5'
-        '/ubuntu/precise/amd64/cm precise-cm5.4.0 contrib'
+        '/ubuntu/trusty/amd64/cm trusty-cm5.9.0 contrib'
         '\ndeb-src http://archive.cloudera.com/cm5/ubuntu'
-        '/precise/amd64/cm precise-cm5.4.0 contrib')
+        '/trusty/amd64/cm trusty-cm5.9.0 contrib')
 
     DEFAULT_CM5_UBUNTU_REPO_KEY_URL = (
         'http://archive.cloudera.com/cm5/ubuntu'
-        '/precise/amd64/cm/archive.key')
+        '/trusty/amd64/cm/archive.key')
 
     CDH5_CENTOS_REPO = (
         '[cloudera-cdh5]'
         '\nname=Cloudera\'s Distribution for Hadoop, Version 5'
         '\nbaseurl=http://archive.cloudera.com/cdh5/redhat/6'
-        '/x86_64/cdh/5.4.0/'
+        '/x86_64/cdh/5.9.0/'
         '\ngpgkey = http://archive.cloudera.com/cdh5/redhat/6'
         '/x86_64/cdh/RPM-GPG-KEY-cloudera'
         '\ngpgcheck = 1')
@@ -54,20 +54,20 @@ class ConfigHelperV540(c_h.ConfigHelper):
         '[cloudera-manager]'
         '\nname=Cloudera Manager'
         '\nbaseurl=http://archive.cloudera.com/cm5/redhat/6'
-        '/x86_64/cm/5.4.0/'
+        '/x86_64/cm/5.9.0/'
         '\ngpgkey = http://archive.cloudera.com/cm5/redhat/6'
         '/x86_64/cm/RPM-GPG-KEY-cloudera'
         '\ngpgcheck = 1')
 
     KEY_TRUSTEE_UBUNTU_REPO_URL = (
         'http://archive.cloudera.com/navigator-'
-        'keytrustee5/ubuntu/precise/amd64/navigator-'
+        'keytrustee5/ubuntu/trusty/amd64/navigator-'
         'keytrustee/cloudera.list')
 
     DEFAULT_KEY_TRUSTEE_UBUNTU_REPO_KEY_URL = (
         'http://archive.cloudera.com/'
         'navigator-keytrustee5/ubuntu/'
-        'precise/amd64/navigator-keytrustee'
+        'trusty/amd64/navigator-keytrustee'
         '/archive.key')
 
     KEY_TRUSTEE_CENTOS_REPO_URL = (
@@ -77,8 +77,8 @@ class ConfigHelperV540(c_h.ConfigHelper):
 
     DEFAULT_SWIFT_LIB_URL = (
         'https://repository.cloudera.com/artifactory/repo/org'
-        '/apache/hadoop/hadoop-openstack/2.6.0-cdh5.4.0'
-        '/hadoop-openstack-2.6.0-cdh5.4.0.jar')
+        '/apache/hadoop/hadoop-openstack/2.6.0-cdh5.9.0'
+        '/hadoop-openstack-2.6.0-cdh5.9.0.jar')
 
     HIVE_SERVER2_SENTRY_SAFETY_VALVE = f.get_file_text(
         path_to_config + 'hive-server2-sentry-safety.xml')
@@ -122,13 +122,13 @@ class ConfigHelperV540(c_h.ConfigHelper):
                                      default_value=True)
 
     def __init__(self):
-        super(ConfigHelperV540, self).__init__()
+        super(ConfigHelperV590, self).__init__()
         self.priority_one_confs = self._load_json(
             self.path_to_config + 'priority-one-confs.json')
         self._init_all_ng_plugin_configs()
 
     def _get_cluster_plugin_configs(self):
-        confs = super(ConfigHelperV540, self)._get_ng_plugin_configs()
+        confs = super(ConfigHelperV590, self)._get_ng_plugin_configs()
         confs += [self.EXECUTOR_EXTRA_CLASSPATH,
                   self.KMS_REPO_URL,
                   self.KMS_REPO_KEY_URL,
@@ -236,6 +236,13 @@ class ConfigHelperV540(c_h.ConfigHelper):
         self.kms_kms_confs = self._load_and_init_configs(
             'kms-kms.json', 'KMS', 'node')
 
+        self.kafka_service = self._load_and_init_configs(
+            'kafka-service.json', 'KAFKA', 'cluster')
+        self.kafka_kafka_broker = self._load_and_init_configs(
+            'kafka-kafka_broker.json', 'KAFKA', 'node')
+        self.kafka_kafka_mirror_maker = self._load_and_init_configs(
+            'kafka-kafka_mirror_maker.json', 'KAFKA', 'node')
+
     def get_required_anti_affinity(self, cluster):
         return self._get_config_value(cluster, self.REQUIRE_ANTI_AFFINITY)
 
