@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Intel Corporation
+# Copyright (c) 2016 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,15 +16,15 @@
 from sahara.conductor import resource as res
 from sahara.plugins.cdh import commands as cmd
 from sahara.plugins.cdh import plugin_utils as pu
-from sahara.plugins.cdh.v5_5_0 import config_helper
-from sahara.plugins.cdh.v5_5_0 import db_helper
+from sahara.plugins.cdh.v5_9_0 import config_helper
+from sahara.plugins.cdh.v5_9_0 import db_helper
 from sahara.plugins import utils as u
 
 
-class PluginUtilsV550(pu.AbstractPluginUtils):
+class PluginUtilsV590(pu.AbstractPluginUtils):
 
     def __init__(self):
-        self.c_helper = config_helper.ConfigHelperV550()
+        self.c_helper = config_helper.ConfigHelperV590()
         self.db_helper = db_helper
 
     def get_role_name(self, instance, service):
@@ -42,6 +42,7 @@ class PluginUtilsV550(pu.AbstractPluginUtils):
             'IMPALAD': 'ID',
             'JOBHISTORY': 'JS',
             'JOURNALNODE': 'JN',
+            'KAFKA_BROKER': 'KB',
             'KMS': 'KMS',
             'MASTER': 'M',
             'NAMENODE': 'NN',
@@ -97,6 +98,9 @@ class PluginUtilsV550(pu.AbstractPluginUtils):
     def get_stdb_rm(self, cluster):
         return u.get_instance(cluster, 'YARN_STANDBYRM')
 
+    def get_kafka_brokers(self, cluster):
+        return u.get_instances(cluster, 'KAFKA_BROKER')
+
     def convert_process_configs(self, configs):
         p_dict = {
             "CLOUDERA": ['MANAGER'],
@@ -124,9 +128,10 @@ class PluginUtilsV550(pu.AbstractPluginUtils):
             "SOLR": ['SOLR_SERVER'],
             "SQOOP": ['SQOOP_SERVER'],
             "KMS": ['KMS'],
-            'YARN_GATEWAY': ['YARN_GATEWAY'],
-            'HDFS_GATEWAY': ['HDFS_GATEWAY'],
-            "JOURNALNODE": ['JOURNALNODE']
+            "YARN_GATEWAY": ['YARN_GATEWAY'],
+            "HDFS_GATEWAY": ['HDFS_GATEWAY'],
+            "JOURNALNODE": ['JOURNALNODE'],
+            "KAFKA": ['KAFKA_BROKER']
         }
         if isinstance(configs, res.Resource):
             configs = configs.to_dict()
@@ -144,7 +149,7 @@ class PluginUtilsV550(pu.AbstractPluginUtils):
             self.db_helper.create_sentry_database(cluster, r)
 
     def _configure_repo_from_inst(self, instance):
-        super(PluginUtilsV550, self)._configure_repo_from_inst(instance)
+        super(PluginUtilsV590, self)._configure_repo_from_inst(instance)
 
         cluster = instance.cluster
         with instance.remote() as r:
