@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Mirantis Inc.
+# Copyright (c) 2016 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,24 +14,86 @@
 # limitations under the License.
 
 from sahara.i18n import _
-from sahara.plugins.cdh.v5_3_0 import plugin_utils as pu
+from sahara.plugins.cdh.v5_9_0 import plugin_utils as pu
 from sahara.plugins.cdh import validation
 from sahara.plugins import exceptions as ex
 from sahara.plugins import utils as u
 
 
-class ValidatorV530(validation.Validator):
-    PU = pu.PluginUtilsV530()
+class ValidatorV590(validation.Validator):
+    PU = pu.PluginUtilsV590()
 
     @classmethod
     def validate_cluster_creating(cls, cluster):
-        super(ValidatorV530, cls).validate_cluster_creating(cluster)
+        super(ValidatorV590, cls).validate_cluster_creating(cluster)
+        cls._hdfs_ha_validation(cluster)
+        cls._yarn_ha_validation(cluster)
         cls._flume_validation(cluster)
         cls._sentry_validation(cluster)
         cls._solr_validation(cluster)
         cls._sqoop_validation(cluster)
         cls._hbase_indexer_validation(cluster)
         cls._impala_validation(cluster)
+        cls._kms_validation(cluster)
+
+    @classmethod
+    def _hdfs_ha_validation(cls, cluster):
+        jn_count = cls._get_inst_count(cluster, 'HDFS_JOURNALNODE')
+        zk_count = cls._get_inst_count(cluster, 'ZOOKEEPER_SERVER')
+
+        require_anti_affinity = cls.PU.c_helper.get_required_anti_affinity(
+            cluster)
+
+        if jn_count > 0:
+            if jn_count < 3:
+                raise ex.InvalidComponentCountException('HDFS_JOURNALNODE',
+                                                        _('not less than 3'),
+                                                        jn_count)
+            if not jn_count % 2:
+                raise ex.InvalidComponentCountException('HDFS_JOURNALNODE',
+                                                        _('be odd'), jn_count)
+            if zk_count < 1:
+                raise ex.RequiredServiceMissingException('ZOOKEEPER',
+                                                         required_by='HDFS HA')
+            if require_anti_affinity:
+                if 'HDFS_SECONDARYNAMENODE' not in\
+                        cls._get_anti_affinity(cluster):
+                    raise ex.NameNodeHAConfigurationError(
+                        _('HDFS_SECONDARYNAMENODE should be enabled '
+                          'in anti_affinity.'))
+                if 'HDFS_NAMENODE' not in cls._get_anti_affinity(cluster):
+                    raise ex.NameNodeHAConfigurationError(
+                        _('HDFS_NAMENODE should be enabled in anti_affinity.'))
+
+    @classmethod
+    def _yarn_ha_validation(cls, cluster):
+        rm_count = cls._get_inst_count(cluster, 'YARN_RESOURCEMANAGER')
+        zk_count = cls._get_inst_count(cluster, 'ZOOKEEPER_SERVER')
+        stdb_rm_count = cls._get_inst_count(cluster, 'YARN_STANDBYRM')
+
+        require_anti_affinity = cls.PU.c_helper.get_required_anti_affinity(
+            cluster)
+
+        if stdb_rm_count > 1:
+            raise ex.InvalidComponentCountException(
+                'YARN_STANDBYRM', _('0 or 1'), stdb_rm_count)
+        if stdb_rm_count > 0:
+            if rm_count < 1:
+                raise ex.RequiredServiceMissingException(
+                    'YARN_RESOURCEMANAGER', required_by='RM HA')
+            if zk_count < 1:
+                raise ex.RequiredServiceMissingException(
+                    'ZOOKEEPER', required_by='RM HA')
+            if require_anti_affinity:
+                if 'YARN_RESOURCEMANAGER' not in\
+                        cls._get_anti_affinity(cluster):
+                    raise ex.ResourceManagerHAConfigurationError(
+                        _('YARN_RESOURCEMANAGER should be enabled in '
+                          'anti_affinity.'))
+                if 'YARN_STANDBYRM' not in cls._get_anti_affinity(cluster):
+                    raise ex.ResourceManagerHAConfigurationError(
+                        _('YARN_STANDBYRM should be'
+                            ' enabled in anti_affinity.'))
 
     @classmethod
     def _flume_validation(cls, cluster):
@@ -156,3 +218,15 @@ class ValidatorV530(validation.Validator):
             if hms_count < 1:
                 raise ex.RequiredServiceMissingException(
                     'HIVE_METASTORE', required_by='IMPALA')
+
+    @classmethod
+    def _kms_validation(cls, cluster):
+
+        kms_count = cls._get_inst_count(cluster, 'KMS')
+        if kms_count > 1:
+            raise ex.InvalidComponentCountException('KMS',
+                                                    _('0 or 1'), kms_count)
+
+    @classmethod
+    def _get_anti_affinity(cls, cluster):
+        return cluster.anti_affinity
