@@ -13,18 +13,24 @@
 # under the License.
 
 
+from oslo_log import log as logging
 from oslo_serialization import jsonutils as json
 import six
 
 import sahara.exceptions as e
 from sahara.i18n import _
 import sahara.plugins.exceptions as ex
+from sahara.plugins.mapr.util import commands as cmd
 from sahara.plugins.mapr.util import event_log as el
 from sahara.plugins.mapr.util import general as g
 from sahara.plugins.mapr.util import service_utils as su
 import sahara.plugins.provisioning as p
 from sahara.utils import files as files
 
+LOG = logging.getLogger(__name__)
+
+SERVICE_UI = 'Web UI'
+
 _INSTALL_PACKAGES_TIMEOUT = 3600
 
 
@@ -62,10 +68,6 @@ class Service(object):
     def dependencies(self):
         return self._dependencies
 
-    @property
-    def ui_info(self):
-        return self._ui_info
-
     @property
     def cluster_defaults(self):
         return self._cluster_defaults
@@ -78,6 +80,9 @@ class Service(object):
     def validation_rules(self):
         return self._validation_rules
 
+    def get_ui_info(self, cluster_context):
+        return self._ui_info
+
     def install(self, cluster_context, instances):
         service_instances = cluster_context.filter_instances(instances,
                                                              service=self)
@@ -88,8 +93,8 @@ class Service(object):
             g.execute_on_instances(_instances,
                                    self._install_packages_on_instance,
                                    _context)
-
-        _install(cluster_context, service_instances)
+        if service_instances:
+            _install(cluster_context, service_instances)
 
     @el.provision_event(instance_reference=1)
     def _install_packages_on_instance(self, instance, cluster_context):
@@ -110,6 +115,13 @@ class Service(object):
 
         return result
 
+    def _set_service_dir_owner(self, cluster_context, instances):
+        service_instances = cluster_context.filter_instances(instances,
+                                                             service=self)
+        LOG.debug("Changing %s service dir owner" % self.ui_name)
+        for instance in service_instances:
+            cmd.chown(instance, 'mapr:mapr', self.service_dir(cluster_context))
+
     def post_install(self, cluster_context, instances):
         pass
 
