@@ -20,8 +20,6 @@ import six
 
 import sahara.plugins.mapr.domain.configuration_file as cf
 import sahara.plugins.mapr.domain.service as s
-import sahara.plugins.mapr.services.hive.hive as hive
-from sahara.plugins.mapr.services.spark import spark
 import sahara.plugins.mapr.util.general as g
 import sahara.utils.files as f
 
@@ -36,6 +34,7 @@ class MySQL(s.Service):
     METASTORE_SPECS = db_spec('metastore', 'maprmetastore', 'mapr')
     RDBMS_SPECS = db_spec('rdbms', 'maprrdbms', 'mapr')
     OOZIE_SPECS = db_spec('oozie', 'maproozie', 'mapr')
+    SENTRY_SPECS = db_spec('sentry', 'maprsentry', 'mapr')
 
     SELECT_DATA = 'mysql -uroot --skip-column-names -e "%s"| grep -E "\w+"'
     GET_DBS_LIST = SELECT_DATA % 'SHOW DATABASES'
@@ -54,10 +53,14 @@ class MySQL(s.Service):
         self._ui_name = 'MySQL'
 
     @staticmethod
-    def _get_db_daemon_name(distro):
+    def _get_db_daemon_name(distro, distro_version):
         if distro.lower() == 'ubuntu':
             return 'mysql'
-        if distro.lower() in ['centos', 'redhatenterpriseserver', 'suse']:
+        if distro.lower() == 'suse':
+            return 'mysqld'
+        if distro.lower() in ['centos', 'redhatenterpriseserver']:
+            if distro_version.split('.')[0] == '7':
+                return 'mariadb'
             return 'mysqld'
         return None
 
@@ -105,7 +108,7 @@ class MySQL(s.Service):
 
     @staticmethod
     def _create_metastore_db(instance, cluster_context, databases, instances):
-        hive_meta = cluster_context.get_instance(hive.HIVE_METASTORE)
+        hive_meta = cluster_context.get_instance('HiveMetastore')
 
         if not hive_meta:
             return
@@ -121,14 +124,25 @@ class MySQL(s.Service):
             MySQL._create_service_db(instance, MySQL.OOZIE_SPECS)
         MySQL._grant_access(instance, MySQL.OOZIE_SPECS, instances)
 
+    @staticmethod
+    def _create_sentry_db(instance, cluster_context, databases, instances):
+        sentry_instance = cluster_context.get_instance('Sentry')
+        if not sentry_instance:
+            return
+        if MySQL.SENTRY_SPECS.db_name not in databases:
+            MySQL._create_service_db(instance, MySQL.SENTRY_SPECS)
+        MySQL._grant_access(instance, MySQL.SENTRY_SPECS, instances)
+
     @staticmethod
     def start_mysql_server(cluster_context):
         LOG.debug('Starting MySQL Server')
         instance = MySQL.get_db_instance(cluster_context)
         distro = cluster_context.distro
+        distro_version = cluster_context.distro_version
         with instance.remote() as r:
             r.execute_command(('service %s restart' %
-                               MySQL._get_db_daemon_name(distro.name)),
+                               MySQL._get_db_daemon_name(distro.name,
+                                                         distro_version)),
                               run_as_root=True)
         LOG.debug('MySQL Server successfully started')
 
@@ -149,8 +163,8 @@ class MySQL(s.Service):
         return list()
 
     @staticmethod
-    def get_db_instance(context):
-        return context.oozie_server or context.get_instance(spark.SPARK_MASTER)
+    def get_db_instance(cluster_context):
+        return cluster_context.oozie_server
 
     @staticmethod
     def create_databases(cluster_context, instances):
@@ -162,6 +176,8 @@ class MySQL(s.Service):
         MySQL._create_oozie_db(db_instance, databases, instances)
         MySQL._create_metastore_db(
             db_instance, cluster_context, databases, instances)
+        MySQL._create_sentry_db(db_instance, cluster_context, databases,
+                                instances)
 
     @staticmethod
     def _create_script_obj(filename, template, **kwargs):
@@ -186,5 +202,6 @@ class MySQL(s.Service):
         MySQL._execute_script(instance, script.remote_path, script.render())
 
     @staticmethod
-    def install_mysql(instance, distro_name):
-        g.run_script(instance, MySQL.MYSQL_INSTALL_SCRIPT, 'root', distro_name)
+    def install_mysql(instance, distro_name, distro_version):
+        g.run_script(instance, MySQL.MYSQL_INSTALL_SCRIPT, 'root', distro_name,
+                     distro_version.split('.')[0])
