@@ -43,7 +43,8 @@ conductor = c.API
 
 ENGINES = [oozie_engine.OozieJobEngine,
            spark_engine.SparkJobEngine,
-           storm_engine.StormJobEngine]
+           storm_engine.StormJobEngine,
+           storm_engine.StormPyleusJobEngine]
 
 
 def _get_job_type(job_execution):
@@ -76,8 +77,11 @@ def _update_job_status(engine, job_execution):
 
 
 def _update_job_execution_extra(cluster, job_execution):
-    if ((CONF.use_namespaces and not CONF.use_floating_ips) or
-            CONF.proxy_command):
+    # tmckay-fp we can make this slightly more efficient in
+    # the use_namespaces case by asking the engine if it knows
+    # the submission machine, and checking if that machine has
+    # a floating ip.
+    if (CONF.use_namespaces or CONF.proxy_command):
         info = cluster.node_groups[0].instances[0].remote().get_neutron_info()
         extra = job_execution.extra.copy()
         extra['neutron'] = info
@@ -132,8 +136,8 @@ def run_job(job_execution_id):
     try:
         _run_job(job_execution_id)
     except Exception as ex:
-        LOG.warning(
-            _LW("Can't run job execution (reason: {reason})").format(
+        LOG.exception(
+            _LE("Can't run job execution (reason: {reason})").format(
                 reason=ex))
 
         job_execution = conductor.job_execution_get(
@@ -214,8 +218,8 @@ def update_job_status(job_execution_id):
     try:
         get_job_status(job_execution_id)
     except Exception as e:
-        LOG.error(_LE("Error during update job execution {job}: {error}")
-                  .format(job=job_execution_id, error=e))
+        LOG.exception(_LE("Error during update job execution {job}: {error}")
+                      .format(job=job_execution_id, error=e))
 
 
 def update_job_statuses(cluster_id=None):
