@@ -59,7 +59,7 @@ def _is_xfs_enabled(cluster):
 
 
 def _get_os_distrib(remote):
-    return remote.execute_command('lsb_release -is')[1].strip().lower()
+    return remote.get_os_distrib()
 
 
 def _check_installed_xfs(instance):
@@ -143,12 +143,25 @@ def _find_instance_devices(instance):
             "mount | awk '$1 ~ /^\/dev/ {print $1}'")
         mounted_dev = mounted_info.split()
 
+        # find and ignore Nova config drive
+        for label in ("config-2", "CONFIG-2"):
+            code, nova_config_drive = r.execute_command(
+                "/sbin/blkid -t LABEL=\"%s\" -odevice" % label,
+                raise_when_error=False,
+                run_as_root=True
+            )
+            drive_name = nova_config_drive.strip()
+            if code == 0 and drive_name in attached_dev:
+                attached_dev.remove(drive_name)
+                break
+
     # filtering attached devices, that should not be mounted
     for dev in attached_dev[:]:
         idx = re.sub("\D", "", dev)
         if idx:
             if dev in mounted_dev:
-                attached_dev.remove(re.sub("\d", "", dev))
+                if re.sub("\d", "", dev) in attached_dev:
+                    attached_dev.remove(re.sub("\d", "", dev))
                 attached_dev.remove(dev)
 
     for dev in attached_dev[:]:
